"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _TabColor = require("../../assets/TabColor");

var _TabStyle = require("../../assets/TabStyle");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const FloatingTabBar = _ref => {
  let {
    state,
    descriptors,
    navigation,
    maxWidth = _reactNative.Dimensions.get('window').width - 30,
    height = 62,
    darkMode = false,
    colorPalette = _TabColor.main_colors,
    closeIcon,
    openIcon,
    initialOpen = false,
    floatingPosition = 'right'
  } = _ref;
  const BACKGROUND_COLOR = darkMode ? colorPalette.dark : colorPalette.light;
  const FOREGROUND_COLOR = darkMode ? colorPalette.light : colorPalette.dark;
  const [isShowContent, setShowContent] = (0, _react.useState)(initialOpen);
  const toggleAnimation = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  let floatingPositionStyle = {};

  switch (floatingPosition) {
    case 'left':
      floatingPositionStyle = {
        bottom: 0,
        left: 0
      };
      break;

    default:
      floatingPositionStyle = {
        bottom: 0,
        right: 0
      };
  }

  (0, _react.useEffect)(() => {
    onToggleAnimation(isShowContent ? 1 : 0);
  }, [isShowContent]);

  const onToggle = () => {
    setShowContent(!isShowContent);
  };

  const onToggleAnimation = value => {
    _reactNative.Animated.timing(toggleAnimation, {
      toValue: value,
      duration: 500,
      useNativeDriver: false,
      easing: _reactNative.Easing.bezier(0.33, 1, 0.68, 1)
    }).start();
  };

  const renderToggleIcon = icon => {
    if (icon === undefined || icon === null) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: { ..._TabStyle.FloatingStyle.itemIconNotFound,
          borderColor: FOREGROUND_COLOR
        }
      });
    }

    return icon({
      color: FOREGROUND_COLOR,
      size: 23
    });
  };

  const widthToggle = toggleAnimation.interpolate({
    inputRange: [0, 1],
    outputRange: [height, 600]
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: _TabStyle.FloatingStyle.container
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_TabStyle.FloatingStyle.content, {
      backgroundColor: BACKGROUND_COLOR,
      maxWidth: maxWidth,
      width: widthToggle,
      height: height
    }, floatingPositionStyle]
  }, floatingPosition.includes('left') ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_TabStyle.FloatingStyle.toggleItem, {
      backgroundColor: isShowContent ? colorPalette.dark + '12' : 'transparent',
      borderTopStartRadius: 50,
      borderBottomStartRadius: 50,
      borderTopEndRadius: 0,
      borderBottomEndRadius: 0
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    accessibilityRole: "button",
    onPress: onToggle,
    style: _TabStyle.FloatingStyle.touchableItem
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _TabStyle.FloatingStyle.toggleIconLayer
  }, isShowContent ? renderToggleIcon(closeIcon) : renderToggleIcon(openIcon)))) : null, state.routes.map((route, index) => {
    const focusAnimation = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
    const {
      options
    } = descriptors[route.key];
    const label = options.tabBarLabel !== undefined ? options.tabBarLabel : options.label !== undefined ? options.label : options.title !== undefined ? options.title : route.name;
    const labelStyle = options.tabBarLabelStyle !== undefined ? options.tabBarLabelStyle : options.labelStyle !== undefined ? options.labelStyle : {};
    let color = options.tabBarActiveTintColor !== undefined ? options.tabBarActiveTintColor : options.color !== undefined ? options.color : colorPalette.primary;
    color = (color || '').charAt(0) == '#' ? color : colorPalette[color];
    const icon = options.tabBarIcon !== undefined ? options.tabBarIcon : options.icon !== undefined ? options.icon : null;

    const renderIcon = focused => {
      if (icon === undefined || icon === null) {
        return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
          style: { ..._TabStyle.FloatingStyle.itemIconNotFound,
            borderColor: focused ? color : FOREGROUND_COLOR
          }
        });
      }

      return icon({
        focused,
        color: focused ? color : FOREGROUND_COLOR,
        size: 23
      });
    };

    const isFocused = state.index === index;

    const onPress = () => {
      const event = navigation.emit({
        type: 'tabPress',
        target: route.key,
        canPreventDefault: true
      });

      if (!isFocused && !event.defaultPrevented) {
        navigation.navigate(route.name);
      }
    };

    const onLongPress = () => {
      navigation.emit({
        type: 'tabLongPress',
        target: route.key
      });
    };

    (0, _react.useEffect)(() => {
      if (isFocused) {
        onFocusedAnimation();
      } else {
        notFocusedAnimation();
      }
    }, [isFocused]);

    const onFocusedAnimation = () => {
      _reactNative.Animated.timing(focusAnimation, {
        toValue: 1,
        duration: 500,
        useNativeDriver: true,
        easing: _reactNative.Easing.bezier(0.33, 1, 0.68, 1)
      }).start();
    };

    const notFocusedAnimation = () => {
      _reactNative.Animated.timing(focusAnimation, {
        toValue: 0,
        duration: 500,
        useNativeDriver: true,
        easing: _reactNative.Easing.bezier(0.33, 1, 0.68, 1)
      }).start();
    };

    const translateYIcon = focusAnimation.interpolate({
      inputRange: [0, 1],
      outputRange: [0, -8]
    });
    const translateYText = focusAnimation.interpolate({
      inputRange: [0, 1],
      outputRange: [0, 13]
    });
    const scaleText = focusAnimation.interpolate({
      inputRange: [0, 0.5, 1],
      outputRange: [0, 0, 1]
    });
    return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      key: index,
      style: [_TabStyle.FloatingStyle.item, {
        display: isShowContent ? 'flex' : 'none'
      }]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      accessibilityRole: "button",
      accessibilityState: isFocused ? {
        selected: true
      } : {},
      accessibilityLabel: options.tabBarAccessibilityLabel,
      testID: options.tabBarTestID,
      onPress: onPress,
      onLongPress: onLongPress,
      style: _TabStyle.FloatingStyle.touchableItem
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: [_TabStyle.FloatingStyle.itemIconLayer, {
        transform: [{
          translateY: translateYIcon
        }]
      }]
    }, renderIcon(isFocused)), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      pointerEvents: "none",
      style: [_TabStyle.FloatingStyle.itemTextLayer, {
        transform: [{
          translateY: translateYText
        }, {
          scale: scaleText
        }]
      }]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      numberOfLines: 1,
      style: [_TabStyle.FloatingStyle.itemText, labelStyle, {
        color: isFocused ? color : FOREGROUND_COLOR
      }]
    }, label))));
  }), floatingPosition.includes('right') ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_TabStyle.FloatingStyle.toggleItem, {
      backgroundColor: isShowContent ? colorPalette.dark + '12' : 'transparent',
      borderTopStartRadius: 0,
      borderBottomStartRadius: 0,
      borderTopEndRadius: 50,
      borderBottomEndRadius: 50
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    accessibilityRole: "button",
    onPress: onToggle,
    style: _TabStyle.FloatingStyle.touchableItem
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _TabStyle.FloatingStyle.toggleIconLayer
  }, isShowContent ? renderToggleIcon(closeIcon) : renderToggleIcon(openIcon)))) : null));
};

var _default = FloatingTabBar;
exports.default = _default;
//# sourceMappingURL=FloatingTabBar.js.map